# Entrypoints

Application entrypoints for various frameworks.

## Overview

The entrypoints module provides integration with various web frameworks and platforms to launch haolib applications.

## Components

- **Abstract**: Base abstract classes for entrypoints
- **FastAPI**: FastAPI web framework integration
- **FastMCP**: FastMCP integration
- **FastStream**: FastStream streaming integration
- **Taskiq**: Taskiq task queue integration
